@@ -61,6 +61,7 @@ class CompositeMap:
         self._number_of_samples_ = experiment.number_of_samples
         self.list_input_files = experiment.list_input_files
         self.reference_sample = None                # designated reference sample; all RT is aligned to this sample
+        self.dict_scan_rtime = {}                   # will populate scan number to Rtime mapping via reference_sample
 
         self.MassGrid = None                        # will be DF
         self.FeatureTable = None
@@ -85,11 +86,12 @@ class CompositeMap:
 
     def initiate_mass_grid(self, init_samples):
         '''
-        Create MassGrid for whole experiment
-        Use list_samples (list of Sample instances) to initiate MassGrid.
+        Initiate MassGrid for whole experiment.
+
+        Input
+        =====
+        list_samples: list of Sample instances, used to initiate MassGrid.
         Each Sample has list_mass_tracks and anchor_mz_pairs.
-        The m/z of reference is taken as mean of these initiation samples (id_mz_str not updated). Afterwards, 
-        the ref m/z isn't changed when single samples are added for performance/complexity reasons.
 
         All mass traces are included at this stage, regardless if peaks are detected, because
         peak detection will be an improved process on the composite traces.
@@ -114,8 +116,12 @@ class CompositeMap:
         reference_sample.rt_cal_dict = reference_sample.reverse_rt_cal_dict = _d
         self.reference_sample = self.experiment.reference_sample = reference_sample
         # note: other samples are aligned to this ref
+        self.dict_scan_rtime = dict(zip(reference_sample.rt_numbers, reference_sample.list_retention_time))
 
         print("\nInitiating MassGrid, ...\n    The reference sample is:\n    ||* %s *||\n" %reference_sample.input_file)
+        print("Max _retention_time is %4.2f at scan number %d.\n" %(max(reference_sample.list_retention_time),
+                                                                    max(reference_sample.rt_numbers)))
+        # print("Max intensity is %d and median intensity is %d." %(        ))
 
         self.reference_anchor_pairs = reference_sample.anchor_mz_pairs
         self._mz_landmarks_ = flatten_tuplelist(reference_sample.anchor_mz_pairs)
@@ -169,23 +175,21 @@ class CompositeMap:
 
     def optimize_mass_grid(self):
         '''
-        This inspects split or misaligned regions of m/z tracks.
-        Problematic definition will persist in each sample's mass tracks,
-        e.g. about 50 mass tracks are too close to each other in our plasma data; 200 in Zurich E. coli data.
-
-        merge close mass tracks unless MassGrid suggests multiple features; 
-        for split tracks in same samples, replace them by merged tracks and new id_numbers.
-
-        For low-selectivity mass tracks, could do 2-D deconvolution.?
-
+        Place holder - to inspect split or misaligned regions of m/z tracks.
         Not really needed now, after mass_tracks in each sample are cleaned up for m/z overlap.
 
-        '''
+        Potential optimizations to consider, e.g. 2-D deconvolution for low-selectivity mass tracks.
         # also check for empty tracks after composite?
         # watch out for indices used by other variables, e.g. _mz_landmarks_
+        '''
         pass
 
 
+    def mock_rentention_alignment(self):
+        for sample in self.experiment.samples_nonreference:
+            sample.rt_cal_dict, sample.reverse_rt_cal_dict = mock_rt_calibration(sample.rt_numbers, self.reference_sample.rt_numbers)
+
+
     def align_retention_time(self):
         '''
         Because RT will not match precisely btw samples, it's remapped to a common set of time coordinates.
@@ -210,6 +214,7 @@ class CompositeMap:
         for SM in self.experiment.samples_nonreference:
             self.calibrate_sample_RT(SM, cal_min_peak_height=cal_min_peak_height, MIN_PEAK_NUM=MIN_PEAK_NUM)
         
+
     def calibrate_sample_RT(self, 
                                 sample, 
                                 calibration_fuction=rt_lowess_calibration, 
@@ -288,23 +293,38 @@ class CompositeMap:
         '''
         Using peaks.deep_detect_elution_peaks on composite mass tracks.
         Results are deemed as features, because it's at Experiment level.
-        Peak area and height are cumulated from all samples. Not trying to average because some peaks are only few samples.
+        Peak area and height are cumulated from all samples. Not trying to average because some peaks are in only few samples.
         '''
         self.composite_mass_tracks = self.make_composite_mass_tracks()
         print("\nPeak detection on %d composite mass tracks, ...\n" %len(self.composite_mass_tracks))
 
+        # to specify parameters here according to Experiment parameters
+        min_peak_height = self.experiment.parameters['min_peak_height']
+        min_prominence_threshold = self.experiment.parameters['min_prominence_threshold']
+        min_fwhm = round( 0.5 * self.experiment.parameters['min_timepoints'] )
+        snr = self.experiment.parameters['signal_noise_ratio']
+
         for _, mass_track in self.composite_mass_tracks.items():
-            self.FeatureList +=  deep_detect_elution_peaks( mass_track, 
-                                                            max_rt_number = self.experiment.number_scans,
-                                                            min_peak_height=10000, min_fwhm=3, min_prominence_threshold=5000, wlen=50, 
-                snr=2, min_prominence_ratio=0.1,
-                iteration=True
-                    )           # to specify parameters here according to Experiment parameters
+            if max(mass_track['intensity']) > min_peak_height:
+                self.FeatureList +=  deep_detect_elution_peaks( mass_track, 
+                                        max_rt_number=self.experiment.number_scans,
+                                        min_peak_height=min_peak_height, min_fwhm=min_fwhm, 
+                                        min_prominence_threshold=min_prominence_threshold, 
+                                        snr=snr,
+                                        wlen=50, min_prominence_ratio=0.1,
+                                        iteration=True
+                                        ) 
 
         ii = 0
         for peak in self.FeatureList:
             ii += 1
             peak['id_number'] = 'F'+str(ii)
+            # convert scan numbers to rtime
+            try:
+                peak['rtime'] = self.dict_scan_rtime[peak['apex']]
+                peak['rtime_left_base'], peak['rtime_right_base'] = self.dict_scan_rtime[peak['left_base']], self.dict_scan_rtime[peak['right_base']]
+            except KeyError:
+                print("Peak rtime out of bound on", ii)
 
         self.generate_feature_table()
 
@@ -376,7 +396,7 @@ class CompositeMap:
         FeatureTable = pd.DataFrame(self.FeatureList)
         for SM in self.experiment.all_samples:
             if SM.rt_cal_dict:
-                FeatureTable[SM.input_file] = self.extract_features_per_sample(SM)
+                FeatureTable[SM.name] = self.extract_features_per_sample(SM)          # SM.input_file
 
         self.FeatureTable = FeatureTable
 
