@@ -85,20 +85,35 @@ class ext_Experiment(Experiment):
         #      start DB after init
         
         self.process_all_without_export()
-        # 
         self.CMAP.MassGrid.to_csv(
             os.path.join(self.parameters['outdir'], self.parameters['mass_grid_mapping']) )
-
-        self.annotate()
-
         self.export_feature_table()
+        self.annotate()
 
 
     def process_all_without_export(self):
+
+        #
+        # Do one sample
+        #
+
         self.CMAP = CompositeMap(self)
         self.CMAP.construct_mass_grid( self.process_initiation_samples() )
-        self.CMAP.align_retention_time()
-        # some samples could fail alignment; can be processed and aligned at the end
+
+
+        # automatic update of parameters based on ref sample
+
+
+
+        if self.parameters['rt_align']:
+            self.CMAP.align_retention_time()
+            # some samples could fail alignment; can be processed and aligned at the end
+
+            # add 3rd option of RT align
+
+        else:
+            self.CMAP.mock_rentention_alignment()
+
         self.CMAP.global_peak_detection()
 
 
@@ -115,9 +130,10 @@ class ext_Experiment(Experiment):
         mz_tolerance_ppm = self.parameters['mz_tolerance']
         min_intensity = self.parameters['min_intensity_threshold']
         min_timepoints = self.parameters['min_timepoints']
+        min_peak_height = self.parameters['min_peak_height']
         try:
             SM = SimpleSample(self, self.mode, input_file)
-            SM.process( mz_tolerance_ppm, min_intensity, min_timepoints)
+            SM.process( mz_tolerance_ppm, min_intensity, min_timepoints, min_peak_height)
             # sample id, assigned by index in self.list_input_files.
             # DB commit
             return SM
@@ -154,10 +170,10 @@ class ext_Experiment(Experiment):
         EED.extend_empCpd_annotation(self.KCD)
         EED.annotate_singletons(self.KCD)
 
-        self.export_peak_annotation(EED.dict_empCpds, self.KCD, 'peak_annotation')
+        self.export_peak_annotation(EED.dict_empCpds, self.KCD, 'Feature_annotation')
         
         # also exporting JSON
-        outfile = os.path.join(self.parameters['outdir'], 'annotated_empricalCompounds.json')
+        outfile = os.path.join(self.parameters['outdir'], 'Annotated_empricalCompounds.json')
         with open(outfile, 'w', encoding='utf-8') as f:
             json.dump(EED.dict_empCpds, f, cls=NpEncoder, ensure_ascii=False, indent=2)
 
@@ -240,20 +256,22 @@ class ext_Experiment(Experiment):
                 'goodness_fitting': 0.9466921897715592,
                 'snr': 35.0}]},...
         '''
-        s = "[peak]id_number\tmz\tapex\t[EmpCpd]interim_id\t[EmpCpd]ion_relation\tneutral_formula\tneutral_formula_mass\tmatched_DB_shorts\tmatched_DB_records\n"
+        s = "[peak]id_number\tmz\trtime\tapex(scan number)\t[EmpCpd]interim_id\t[EmpCpd]ion_relation\tneutral_formula\tneutral_formula_mass\
+        \tname_1st_guess\tmatched_DB_shorts\tmatched_DB_records\n"
         for ii, V in dict_empCpds.items():
-            matched_DB_shorts, matched_DB_records = '', ''
+            name_1st_guess, matched_DB_shorts, matched_DB_records = '', '', ''
             if 'list_matches' in V:
                 list_matches = V['list_matches']
-                #if list_matches:
-                matched_DB_shorts = ", ".join([ "(" + KCD.short_report_emp_cpd(xx[0]) + ")"  for xx in list_matches])
-                matched_DB_records = ", ".join([str(xx) for xx  in list_matches])
+                if list_matches:
+                    name_1st_guess = KCD.mass_indexed_compounds[list_matches[0][0]]['compounds'][0]['name']
+                    matched_DB_shorts = ", ".join([ "(" + KCD.short_report_emp_cpd(xx[0]) + ")"  for xx in list_matches])
+                    matched_DB_records = ", ".join([str(xx) for xx  in list_matches])
 
             for peak in V['MS1_pseudo_Spectra']:
                 s += '\t'.join([str(x) for x in [
-                    peak['id_number'], peak['mz'], peak['apex'], V['interim_id'], peak.get('ion_relation', ''),
+                    peak['id_number'], peak['mz'], peak['rtime'], peak['apex'], V['interim_id'], peak.get('ion_relation', ''),
                     V['neutral_formula'], V['neutral_formula_mass'],
-                    matched_DB_shorts, matched_DB_records]]) + "\n"
+                    name_1st_guess, matched_DB_shorts, matched_DB_records]]) + "\n"
 
         outfile = os.path.join(self.parameters['outdir'],export_file_name_prefix + '.tsv')
         with open(outfile, 'w') as O:
@@ -262,24 +280,24 @@ class ext_Experiment(Experiment):
         print("\nAnnotation of %d Empirical compounds was written to %s." %(len(dict_empCpds), outfile))
 
 
-    def export_feature_table(self, full=True, outfile='cmap_feature_table.csv'):
+    def export_feature_table(self, full=False, outfile='cmap_feature_table.tsv'):
         '''
-        Will need real RT time;
-        Selectivity in m/z, RT and overall
-        
+        Will better format cells
+
+        ['rtime_left_base'], ['rtime_right_base']
         '''
         outfile = os.path.join(self.parameters['outdir'], self.parameters['output_feature_table'])
         if full:
-            self.CMAP.FeatureTable.to_csv(outfile)
+            self.CMAP.FeatureTable.to_csv(outfile, index=False, sep="\t")
+
         else:
-            # select columns to export
-            pass
+            use_cols = [ 'id_number', 'mz', 'rtime', 'parent_masstrack_id', 'peak_area', 'cSelectivity', 'goodness_fitting', 'snr',
+                    ] + [sample.name for sample in self.all_samples]
+            self.CMAP.FeatureTable[use_cols].to_csv(outfile, index=False, sep="\t")
 
         print("\n\nFeature table (%d) was written to %s.\n\n" %(self.CMAP.FeatureTable.shape[0], outfile))
 
 
-
-
     def export_feature_table_old__(self, FeatureList, outfile='feature_table.tsv'):
         '''
         FeatureList: a list of namedTuples, i.e. Features; Output two files, one main, another low quality features.
